@@ -10,7 +10,11 @@ dataset_description = {
     "Procedure" : Constants.NIDM_PROJECT_DESCRIPTION,
     "License" : Constants.NIDM_PROJECT_LICENSE,
     "ReferencesAndLinks" : Constants.NIDM_PROJECT_REFERENCES,
-    "Authors" : Constants.NIDM_AUTHOR
+    "Authors" : Constants.NIDM_AUTHOR,
+    "DatasetDOI" : Constants.NIDM_DOI,
+    "Funding" : Constants.NIDM_FUNDING,
+    "HowToAcknowledge" : Constants.NIDM_ACKNOWLEDGEMENTS
+
 }
 
 #BIDS Participants file -> NIDM constants mappings
@@ -33,7 +37,8 @@ scans = {
     "T2w" : Constants.NIDM_MRI_T2,
     "inplaneT2" : Constants.NIDM_MRI_T2,
     "bold" : Constants.NIDM_MRI_FLOW,
-    "dti" : Constants.NIDM_MRI_DIFFUSION_TENSOR
+    "dti" : Constants.NIDM_MRI_DIFFUSION_TENSOR,
+    "asl" : Constants.NIDM_MRI_ASL
 }
 #JSON file keys
 json_keys = {
@@ -41,13 +46,33 @@ json_keys = {
     "run" : Constants.NIDM_ACQUISITION_ENTITY,
     "ImageType" : Constants.DICOM["ImageType"],
     "ManufacturerModelName" : Constants.DICOM["ManufacturerModelName"],
+    "Manufacturer" : Constants.DICOM["Manufacturer"],
     "ScanningSequence" : Constants.DICOM["ScanningSequence"],
     "SequenceVariant" : Constants.DICOM["SequenceVariant"],
     "ScanOptions" : Constants.DICOM["ScanOptions"],
     "MRAcquisitionType" : Constants.DICOM["MRAcquisitionType"],
     "SequenceName" : Constants.DICOM["SequenceName"],
     "RepetitionTime" : Constants.DICOM["RepetitionTime"],
-    "EchoTime" : Constants.DICOM["EchoTime"],
+    "RepetitionTimePreparation" : Constants.BIDS["RepetitionTimePreparation"],
+    "ArterialSpinLabelingType" : Constants.BIDS["ArterialSpinLabelingType"],
+    "PostLabelingDelay" : Constants.BIDS["PostLabelingDelay"],
+    "BackgroundSuppression" : Constants.BIDS["BackgroundSuppression"],
+    "BackgroundSuppressionPulseTime" : Constants.BIDS["BackgroundSuppressionPulseTime"],
+    "BackgroundSuppressionNumberPulses" : Constants.BIDS["BackgroundSuppressionNumberPulses"],
+    "LabelingLocationDescription" : Constants.BIDS["LabelingLocationDescription"],
+    "LookLocker" : Constants.BIDS["LookLocker"],
+    "LabelingEfficiency" : Constants.BIDS["LabelingEfficiency"],
+    "LabelingDuration" : Constants.BIDS["LabelingDuration"],
+    "LabelingPulseAverageGradient" : Constants.BIDS["LabelingPulseAverageGradient"],
+    "LabelingPulseMaximumGradient" : Constants.BIDS["LabelingPulseMaximumGradient"],
+    "LabelingPulseDuration" : Constants.BIDS["LabelingPulseDuration"],
+    "LabelingPulseFlipAngle" : Constants.BIDS["LabelingPulseFlipAngle"],
+    "LabelingPulseInterval" : Constants.BIDS["LabelingPulseInterval"],
+    "PCASLType" : Constants.BIDS["PCASLType"],
+    "M0Type" : Constants.BIDS["M0Type"],
+    "TotalAcquiredPairs" : Constants.BIDS["TotalAcquiredPairs"],
+    "VascularCrushing" : Constants.BIDS["VascularCrushing"],
+    "EchoTime" : Constants.BIDS["EchoTime"],
     "InversionTime" : Constants.DICOM["InversionTime"],
     "NumberOfAverages" : Constants.DICOM["NumberOfAverages"],
     "ImagingFrequency" : Constants.DICOM["ImagingFrequency"],
@@ -66,17 +91,19 @@ json_keys = {
     "ProtocolName": Constants.DICOM["ProtocolName"],
     "TransmitCoilName": Constants.DICOM["TransmitCoilName"],
     "AcquisitionMatrix": Constants.DICOM["AcquisitionMatrix"],
+    "AcquisitionVoxelSize" : Constants.BIDS["AcquisitionVoxelSize"],
     "InPlanePhaseEncodingDirection": Constants.DICOM["InPlanePhaseEncodingDirection"],
-    "FlipAngle": Constants.DICOM["FlipAngle"],
+    "FlipAngle": Constants.BIDS["FlipAngle"],
     "VariableFlipAngleFlag": Constants.DICOM["VariableFlipAngleFlag"],
     "PatientPosition": Constants.DICOM["PatientPosition"],
-    "PhaseEncodingDirection": Constants.NIDM["PhaseEncodingDirection"],
-    "SliceTiming": Constants.NIDM["SliceTiming"],
-    "TotalReadoutTime" : Constants.DICOM["TotalReadoutTime"],
+    "PhaseEncodingDirection": Constants.BIDS["PhaseEncodingDirection"],
+    "SliceTiming": Constants.BIDS["SliceTiming"],
+    "TotalReadoutTime" : Constants.BIDS["TotalReadoutTime"],
     "EffectiveEchoSpacing" : Constants.NIDM["EffectiveEchoSpacing"],
     "NumberDiscardedVolumesByScanner" : Constants.NIDM["NumberDiscardedVolumesByScanner"],
     "NumberDiscardedVolumesByUser" : Constants.NIDM["NumberDiscardedVolumesByUser"],
     "DelayTime" : Constants.NIDM["DelayTime"],
+    "PulseSequenceType" : Constants.DICOM["PulseSequenceName"],
     ###Task Stuff
     "TaskName" : Constants.NIDM_MRI_FUNCTION_TASK
     # "CogAtlasID" :
